PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/rayleigh.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Functions | Variables
rayleigh.py File Reference

## Namespaces
| pawpyseed.core.rayleigh

## Functions
def | pawpyseed.core.rayleigh.planewave (coord)
def | pawpyseed.core.rayleigh.func (coord)
def | pawpyseed.core.rayleigh.rad_int (r)

## Variables
int | pawpyseed.core.rayleigh.k = np.array([0.6,0.2,0.3])*2
| pawpyseed.core.rayleigh.x = np.arange(-8, 8, 0.1)
| pawpyseed.core.rayleigh.y = np.arange(-8, 8, 0.1)
| pawpyseed.core.rayleigh.z = np.arange(-8, 8, 0.1)
| pawpyseed.core.rayleigh.indexing
| pawpyseed.core.rayleigh.grid = np.array([x, y, z])
| pawpyseed.core.rayleigh.w = planewave(grid)
| pawpyseed.core.rayleigh.f = func(grid)
| pawpyseed.core.rayleigh.integrand = w*np.conj(f)
| pawpyseed.core.rayleigh.temp1 = np.trapz(integrand, x, axis = 0)
| pawpyseed.core.rayleigh.temp2 = np.trapz(temp1, y[0,:,:], axis = 0)
| pawpyseed.core.rayleigh.final = np.trapz(temp2, z[0,0,:], axis = 0)
| pawpyseed.core.rayleigh.r = np.arange(0,8,0.1)
| pawpyseed.core.rayleigh.integral = rad_int(r)